@@ -148,7 +148,7 @@ def scan_metadata_processor(
     :Example:
         .. code-block:: powershell
 
-        .\Isogeo_ScanMetadataProcessor.exe --label "Check" --settings .\settings.env check
+        ./Isogeo_ScanMetadataProcessor.exe --label "Check" --settings ./settings.env check
 
     """
     # Load settings
