@@ -44,7 +44,12 @@ reg_digits_parentesis = re.compile(r"^.*?\([^\d]*(\d+)[^\d]*\).*$")
 
 
 class LookupToIsogeo:
-    """Model converter from lookup to Isogeo model."""
+    """Model converter from lookup to Isogeo model.
+
+    :param Lookup in_lookup: source lookup model
+    :param list isogeo_formats: Isogeo formats registry
+    :param Workgroup isogeo_group: Isogeo group
+    """
 
     COORDINATES_ROUND_LEVEL = 3
 
@@ -170,18 +175,21 @@ class LookupToIsogeo:
             except Exception as err:
                 logger.error(
                     "Failed loading the envelope from {}. Using the raw string."
-                    "Trace: {}".format(self.in_lookup.name),
-                    err,
+                    "Trace: {}".format(self.in_lookup.name, err)
                 )
                 out_envelope = json.loads(self.in_lookup.envelope)
 
         return out_envelope
 
     def extract_name(self) -> str:
-        """Extract name."""
+        """Extract dataset name from lookup. \
+        Handle specific cases like FileGDB Open which adds an ugly slash.
+
+        :rtype: str
+        """
         out_name = self.in_lookup.name
 
-        # using open api driver add a forbidden char: '/'
+        # using open api driver add a forbidden char: '/'. Let's remove it.
         if (
             self.match_format_code == "filegdb"
             and self.in_lookup.formatShort == "FILEGDB"
@@ -191,7 +199,11 @@ class LookupToIsogeo:
         return out_name
 
     def extract_path(self) -> str:
-        """Extract path."""
+        """Extract path.
+
+        :return: dataset path
+        :rtype: str
+        """
         out_path = None
         if self.in_lookup.path:
             out_path = self.in_lookup.path
@@ -240,7 +252,11 @@ class LookupToIsogeo:
 
     @property
     def match_format_version(self) -> str:
-        """Guess the format version."""
+        """Try to determine the format version when there is only one.
+
+        :return: format version
+        :rtype: str
+        """
         out_format_version = None
 
         # without format code, no format version
@@ -265,7 +281,11 @@ class LookupToIsogeo:
 
     @property
     def match_geometry_type(self) -> str:
-        """Guess metadata geometry type."""
+        """Match geometry type from lookup (FME) with Isogeo.
+
+        :return: dataset geometry type
+        :rtype: str
+        """
         # matching format
         geometry_type = MATCHER_GEOMETRY.get(self.in_lookup.geometryType)
 
@@ -273,7 +293,11 @@ class LookupToIsogeo:
 
     @property
     def match_type(self) -> str:
-        """Guess metadata type."""
+        """Match dataset type, mainly using the lookup model included helpers.
+
+        :return: metadata type
+        :rtype: str
+        """
         # default type
         out_md_type = "resource"
 
@@ -286,6 +310,12 @@ class LookupToIsogeo:
         return out_md_type
 
     def as_metadata(self) -> Metadata:
+        """Use submethods to return the lookup as an Isogeo metadata model \
+        ready to be created.
+
+        :return: Isogeo metadata converted from source lookup
+        :rtype: Metadata
+        """
         consolidated_md = Metadata(
             _creator=self.group,
             editionProfile="manual",
